@@ -1,4 +1,4 @@
-<?php declare(strict_types=1);
+<?php
 namespace TheSeer\Autoload;
 
 use PHPUnit\Framework\TestCase;
@@ -7,10 +7,10 @@ class ComposerIteratorTest extends TestCase {
 
     public function testRecursionIsHandledProperly() {
         $iterator = new ComposerIterator(new \SplFileInfo(__DIR__ . '/_data/recursion/composer.json'));
-        $expected = [
+        $expected = array(
             __DIR__ . '/_data/recursion/vendor/foo/bar',
             __DIR__ . '/_data/recursion/vendor/bar/foo'
-        ];
+        );
         foreach($iterator as $pos => $entry) {
             $this->assertEquals($expected[$pos], $entry);
         }
